==> orangetool-0.45.tar.gz: orangetool-0.45/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.45] - 2020-12-26
### Added
- `__main__.py`
- `__version__` variable
- `hibernate` function
- `usb_control`, `usb_on` and `usb_off` functions
### Changed
- `dev-requirements.txt` modified
- Test system modified
- `DEBUG` parameter renamed to `debug`
- All parameters moved to `orangetool_params.py`
- Some functions moved to `orangetool_utils.py`
- `ADDRESS` parameter renamed to `address`
- `Zone` parameter renamed to `zone`
- `uptime` and `idletime` functions updated
- Docstrings updated
- `README.md` modified
## [0.35] - 2019-06-01
### Added
- `version_check.py`
- `CODE_OF_CONDUCT.md`
- `ISSUE_TEMPLATE.md`
- `PULL_REQUEST_TEMPLATE.md`
- `CONTRIBUTING.md`
- `test.sh`
- `autopep8.bat`
- `dev-requirements.txt`
- `CHANGELOG.md`
- `MANIFEST.in`

### Changed
- `README.md` modified
- Test system modified
- `restart`, `halt` and `sleep` functions modified
- `hdmi_on` and `hdmi_off` functions modified
- `version` function modified
- `requirements.txt` modified
- `DEVICE` parameter renamed to `device` in `set_ip` function
- `restart` parameter added to `set_ip` function

## [0.25] - 2017-09-14
### Changed
- Minor bug in PyPi dependencies fixed

## [0.24] - 2017-07-21
### Changed
- Minor bugs fixed

## [0.23] - 2017-07-15
### Added
- `Check_update` function


### Changed
- Minor bugs fixed

## [0.22] - 2017-03-30
### Added
- `Version` function
- `Supported_Device_List.md`

### Changed
- Minor bugs fixed

## [0.2] - 2017-03-06
### Added
- `idletime` function
- `mount`,`unmount` functions

### Changed
 - Some bugs fixed

## [0.1] - 2017-02-15
### Added
- Some useful scripts for Orangepi/Raspberrypi boards

[Unreleased]: https://github.com/Moduland/Orangetool/compare/v0.45...dev
[0.45]: https://github.com/Moduland/Orangetool/compare/v0.35...v0.45
[0.35]: https://github.com/Moduland/Orangetool/compare/v0.25...v0.35
[0.25]: https://github.com/Moduland/Orangetool/compare/v0.24...v0.25
[0.24]: https://github.com/Moduland/Orangetool/compare/v0.23...v0.24
[0.23]: https://github.com/Moduland/Orangetool/compare/v0.22...v0.23
[0.22]: https://github.com/Moduland/Orangetool/compare/v0.2...v0.22
[0.2]: https://github.com/Moduland/Orangetool/compare/v0.1...v0.2
[0.1]: https://github.com/Moduland/Orangetool/compare/1e238cd...v0.1

==> orangetool-0.50.tar.gz: orangetool-0.50/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.50] - 2021-01-01
### Added
- `network_control`, `network_enable` and `network_disable` functions
### Changed
- `sync` parameter added to `wakeup` function
- `debug` parameter added to `internet` function
## [0.45] - 2020-12-26
### Added
- `__main__.py`
- `__version__` variable
- `hibernate` function
- `usb_control`, `usb_on` and `usb_off` functions
### Changed
- `dev-requirements.txt` modified
- Test system modified
- `DEBUG` parameter renamed to `debug`
- All parameters moved to `orangetool_params.py`
- Some functions moved to `orangetool_utils.py`
- `ADDRESS` parameter renamed to `address`
- `Zone` parameter renamed to `zone`
- `uptime` and `idletime` functions updated
- Docstrings updated
- `README.md` modified
## [0.35] - 2019-06-01
### Added
- `version_check.py`
- `CODE_OF_CONDUCT.md`
- `ISSUE_TEMPLATE.md`
- `PULL_REQUEST_TEMPLATE.md`
- `CONTRIBUTING.md`
- `test.sh`
- `autopep8.bat`
- `dev-requirements.txt`
- `CHANGELOG.md`
- `MANIFEST.in`

### Changed
- `README.md` modified
- Test system modified
- `restart`, `halt` and `sleep` functions modified
- `hdmi_on` and `hdmi_off` functions modified
- `version` function modified
- `requirements.txt` modified
- `DEVICE` parameter renamed to `device` in `set_ip` function
- `restart` parameter added to `set_ip` function

## [0.25] - 2017-09-14
### Changed
- Minor bug in PyPi dependencies fixed

## [0.24] - 2017-07-21
### Changed
- Minor bugs fixed

## [0.23] - 2017-07-15
### Added
- `Check_update` function


### Changed
- Minor bugs fixed

## [0.22] - 2017-03-30
### Added
- `Version` function
- `Supported_Device_List.md`

### Changed
- Minor bugs fixed

## [0.2] - 2017-03-06
### Added
- `idletime` function
- `mount`,`unmount` functions

### Changed
 - Some bugs fixed

## [0.1] - 2017-02-15
### Added
- Some useful scripts for Orangepi/Raspberrypi boards

[Unreleased]: https://github.com/Moduland/Orangetool/compare/v0.50...dev
[0.50]: https://github.com/Moduland/Orangetool/compare/v0.45...v0.50
[0.45]: https://github.com/Moduland/Orangetool/compare/v0.35...v0.45
[0.35]: https://github.com/Moduland/Orangetool/compare/v0.25...v0.35
[0.25]: https://github.com/Moduland/Orangetool/compare/v0.24...v0.25
[0.24]: https://github.com/Moduland/Orangetool/compare/v0.23...v0.24
[0.23]: https://github.com/Moduland/Orangetool/compare/v0.22...v0.23
[0.22]: https://github.com/Moduland/Orangetool/compare/v0.2...v0.22
[0.2]: https://github.com/Moduland/Orangetool/compare/v0.1...v0.2
[0.1]: https://github.com/Moduland/Orangetool/compare/1e238cd...v0.1
